@@ -2,9 +2,9 @@
 # cosinor function using a GLM
 # available link functions = identity, log, logit, cloglog
 # date = date for daily data, month for monthly data
-# type =  monthly/weekly/daily
+# type =  monthly/weekly/daily/hourly
 # phase results based on 1 cycle per year
-# Jan 2014
+# Aug 2014
 
 cosinor<-function(formula, date, data,family=gaussian(), alpha=0.05,
                   cycles=1, rescheck=FALSE, type='daily', offsetmonth=FALSE,
@@ -14,11 +14,15 @@ cosinor<-function(formula, date, data,family=gaussian(), alpha=0.05,
   this.class=as.character(classes[which(names(data)==date)]) # also used later
   if (!is.logical(offsetmonth)){
     stop("Error: 'offsetmonth' must be of type logical")}
-  if (type!='daily'&type!='weekly'&type!='monthly'){stop("type must be daily, weekly or monthly")}
+  if (type!='daily'&type!='weekly'&type!='monthly'&type!='hourly'){stop("type must be daily, weekly, monthly or hourly")}
+  if (type=='hourly'&length(grep('POSIXct',this.class))==0){
+    stop("date variable must be of class POSIXct when type='hourly'")}
   if (type=='daily'&this.class!='Date'){
     stop("date variable must be of class Date when type='daily'")}
   if (alpha<=0|alpha>=1){stop("alpha must be between 0 and 1")}
-
+  if (type=='hourly'&offsetmonth==TRUE){
+    stop("do not use monthly offset for hourly data")}
+  
   ## original call with defaults (see amer package)
   link<-family$link
   ans <- as.list(match.call())
@@ -30,10 +34,16 @@ cosinor<-function(formula, date, data,family=gaussian(), alpha=0.05,
   parts<-paste(formula)
   f<-as.formula(paste(parts[2],parts[1],parts[3:length(formula)],'+cosw+sinw'))
 
-  ## get the year fraction
+  ## get the year/hour fraction
   to.frac=subset(data,select=date)[,1]
-  class(to.frac)=this.class # return to class (needed for date class)
-  frac<-yrfraction(to.frac,type=type) # 
+  if(type=='hourly'){
+    number = as.numeric(format(to.frac,'%H'))+(as.numeric(format(to.frac,'%M'))/60)+(as.numeric(format(to.frac,'%S'))/60*60)
+    frac = number/24
+  }
+  if(type!='hourly'){
+    class(to.frac)=this.class # return to class (needed for date class)
+    frac = yrfraction(to.frac,type=type) # 
+  }
   data$cosw<-cos(frac*2*pi*cycles)
   data$sinw<-sin(frac*2*pi*cycles)
   newdata<-data.frame(cosw=data$cosw,sinw=data$sinw) # used later
@@ -44,7 +54,7 @@ cosinor<-function(formula, date, data,family=gaussian(), alpha=0.05,
     days = flagleap(data=data, report=FALSE, matchin=TRUE) # get the number of days in each month
     moff = days$ndaysmonth/(365.25/12) # days per month divided by average month length
   }
-  offset<-log(poff*moff)
+  offset <- log(poff*moff)
   # generalized linear model
   model<-glm(f, data=data, family=family, offset=offset)
   s<-summary(model)
@@ -57,11 +67,11 @@ cosinor<-function(formula, date, data,family=gaussian(), alpha=0.05,
   fitted=fitted(model) # standard fitted values
   pred<-s$coefficients[1,1]+(s$coefficients[cindex,1]*newdata$cosw)+
     (s$coefficients[sindex,1]*newdata$sinw)
-                                        # back-transform
+  # back-transform:
   if (s$family$link=='log'){pred<-exp(pred)}
   if (s$family$link=='logit'){pred<-exp(pred)/(1+exp(pred))}
   if (s$family$link=='cloglog'){pred<-1-exp(-exp(pred))}
-                                        # return
+  # return:
   toret<-list()
   toret$call<-call
   toret$glm<-model # changed to model rather than summary
