@@ -10,5 +10,6 @@ plot.Monthmean<-function(x,...){
   box(lwd=1)
   x.ticks=seq(1,12,1)
   x.labels=c('J','F','M','A','M','J','J','A','S','O','N','D')
-  axis(side=1,at=x.ticks,label=x.labels)
+  axis(side=1,at=x.ticks,labels=x.labels)
 }
+
