@@ -4,5 +4,6 @@ print.monthglm<-function(x, ...){
   ## Checks
   if (class(x)!="monthglm"){stop("Object must be of class 'monthglm'")} 
   ## Use GLM function ###
-  print.glm(x$glm, ...)
+  print(x$glm, ...)
 } # end of function
+
